@@ -132,6 +132,8 @@ pub mod error;
 
 mod header;
 pub mod link_format;
+#[macro_use]
+mod log;
 mod observe;
 mod packet;
 mod request;
@@ -143,7 +145,7 @@ mod impl_coap_message;
 pub use header::{
     Header, HeaderRaw, MessageClass, MessageType, RequestType, ResponseType,
 };
-pub use observe::Subject;
+pub use observe::{create_notification, Subject};
 pub use packet::{CoapOption, ContentFormat, ObserveOption, Packet};
 pub use request::CoapRequest;
 pub use response::CoapResponse;
